@@ -92,9 +92,8 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument)
     return true;
 }
 
-bool SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
+QStringList SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
 {
-    Q_UNUSED(iArgument)
     // Initialise the main page
 #ifdef SKG_WEBENGINE
     {
@@ -115,7 +114,7 @@ bool SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
     refreshMainPage();
     connect(m_currentBankDocument, &SKGDocument::transactionSuccessfullyEnded, this, &SKGMonthlyPlugin::refreshMainPage);
 #endif
-    return false;
+    return iArgument;
 }
 
 void SKGMonthlyPlugin::refreshMainPage()
