@@ -49,25 +49,25 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGImportPluginMny();
+    ~SKGImportPluginMny() override;
 
     /**
      * To know if import is possible with this plugin
      */
-    virtual bool isImportPossible() override;
+    bool isImportPossible() override;
 
     /**
      * Import a file
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError importFile() override;
+    SKGError importFile() override;
 
     /**
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual QString getMimeTypeFilter() const override;
+    QString getMimeTypeFilter() const override;
 
 
 private:
