@@ -194,7 +194,6 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
 
     // Get last argument
     connect(this, &SKGImportExportPlugin::importFileName, this, [ = ](const QString & iFileName) {
-        SKGTRACE << "HELLO" << endl;
         this->importFile(iFileName, true);
     }, Qt::QueuedConnection);
 
@@ -208,18 +207,18 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument)
     return true;
 }
 
-bool SKGImportExportPlugin::processArguments(const QStringList& iArgument)
+QStringList SKGImportExportPlugin::processArguments(const QStringList& iArgument)
 {
     SKGTRACEINFUNC(10);
-    bool output = false;
-    int nbArg = iArgument.count();
+    QStringList output = iArgument;
+    int nbArg = output.count();
     if (nbArg) {
-        QString filename = iArgument.at(nbArg - 1);
+        QString filename = output.at(nbArg - 1);
         QString extension = QFileInfo(filename).suffix().toUpper();
         QString extensionDocument = m_currentBankDocument->getFileExtension().toUpper();
         if (QFile(filename).exists() && extension != extensionDocument) {
             Q_EMIT importFileName(filename);
-            output = true;
+            output.pop_back();
         }
     }
     return output;
