@@ -993,7 +993,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
     // Search duplicate number on operation
     if (!iIgnoredAdvice.contains(QStringLiteral("skgoperationplugin_duplicate"))) {
         nbConcurrentCheckTargeted++;
-        m_currentBankDocument->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT count(1), t_ACCOUNT, i_number FROM v_operation_display WHERE i_number!=0 GROUP BY t_ACCOUNT, i_number HAVING count(1)>1 ORDER BY count(1) DESC"), [ & ](const SKGStringListList & iResult) {
+        m_currentBankDocument->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT count(1), t_ACCOUNT, t_number FROM v_operation_display WHERE t_number!='' GROUP BY t_ACCOUNT, t_number HAVING count(1)>1 ORDER BY count(1) DESC"), [ & ](const SKGStringListList & iResult) {
             int nb = iResult.count();
             SKGAdvice::SKGAdviceActionList autoCorrections;
             for (int i = 1; i < nb; ++i) {  // Ignore header
@@ -1446,7 +1446,7 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 
         // Call operation plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?title_icon=security-low&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations of '%1' with duplicate number %2", account, num)) %
-                                               "&operationWhereClause=" % SKGServices::encodeForUrl("i_number=" % SKGServices::stringToSqlString(num) % " AND t_ACCOUNT='" % SKGServices::stringToSqlString(account) % '\''));
+                                               "&operationWhereClause=" % SKGServices::encodeForUrl("t_number='" % SKGServices::stringToSqlString(num) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(account) % '\''));
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgoperationplugin_notreconciliated|"))) {
         // Get parameters
