@@ -45,7 +45,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGSplitTableDelegate();
+    ~SKGSplitTableDelegate() override;
 
     /**
      * Returns the widget used to edit the item specified by index for editing.
@@ -55,9 +55,9 @@ public:
      * @param index index
      * @return the widget
      */
-    virtual QWidget* createEditor(QWidget* iParent,
-                                  const QStyleOptionViewItem& option,
-                                  const QModelIndex& index) const override;
+    QWidget* createEditor(QWidget* iParent,
+                          const QStyleOptionViewItem& option,
+                          const QModelIndex& index) const override;
 
     /**
      * Set the data to be shown in the delegate. For the quantity column,
@@ -66,7 +66,7 @@ public:
      * @param editor
      * @param index
      */
-    virtual void setEditorData(QWidget* editor, const QModelIndex& index) const override;
+    void setEditorData(QWidget* editor, const QModelIndex& index) const override;
 
     /**
      * Get the data to be shown in the model. For the quantity column,
@@ -77,7 +77,7 @@ public:
      * @param model
      * @param index
      */
-    virtual void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const override;
+    void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const override;
 
     /**
      * Add a parameter
