@@ -43,100 +43,99 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGUnitPlugin();
+    ~SKGUnitPlugin() override;
 
     /**
      * Called to initialise the plugin
      * @param iDocument the main document
-     * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) override;
+    bool setupActions(SKGDocument* iDocument) override;
 
     /**
      * The page widget of the plugin.
      * @return The page widget of the plugin
      */
-    virtual SKGTabPage* getWidget() override;
+    SKGTabPage* getWidget() override;
 
     /**
      * The number of dashboard widgets of the plugin.
      * @return The number of dashboard widgets of the plugin
      */
-    virtual int getNbDashboardWidgets() override;
+    int getNbDashboardWidgets() override;
 
     /**
      * Get a dashboard widget title of the plugin.
      * @param iIndex the index of the widget
      * @return The title
      */
-    virtual QString getDashboardWidgetTitle(int iIndex) override;
+    QString getDashboardWidgetTitle(int iIndex) override;
 
     /**
      * Get a dashboard widget of the plugin.
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGBoardWidget* getDashboardWidget(int iIndex) override;
+    SKGBoardWidget* getDashboardWidget(int iIndex) override;
 
     /**
      * Must be modified to refresh widgets after a modification.
      */
-    virtual void refresh() override;
+    void refresh() override;
 
     /**
      * The preference widget of the plugin.
      * @return The preference widget of the plugin
      */
-    virtual QWidget* getPreferenceWidget() override;
+    QWidget* getPreferenceWidget() override;
 
     /**
      * The preference skeleton of the plugin.
      * @return The preference skeleton of the plugin
      */
-    virtual KConfigSkeleton* getPreferenceSkeleton() override;
+    KConfigSkeleton* getPreferenceSkeleton() override;
 
     /**
      * The title of the plugin.
      * @return The title of the plugin
      */
-    virtual QString title() const override;
+    QString title() const override;
 
     /**
      * The icon of the plugin.
      * @return The icon of the plugin
      */
-    virtual QString icon() const override;
+    QString icon() const override;
 
     /**
      * The toolTip of the plugin.
      * @return The toolTip of the plugin
      */
-    virtual QString toolTip() const override;
+    QString toolTip() const override;
 
     /**
      * The tips list of the plugin.
      * @return The tips list of the plugin
      */
-    virtual QStringList tips() const override;
+    QStringList tips() const override;
 
     /**
      * Must be implemented to set the position of the plugin.
      * @return integer value between 0 and 999 (default = 999)
      */
-    virtual int getOrder() const override;
+    int getOrder() const override;
 
     /**
      * Must be implemented to know if a plugin must be display in pages chooser.
      * @return true of false (default = false)
      */
-    virtual bool isInPagesChooser() const override;
+    bool isInPagesChooser() const override;
 
     /**
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice) override;
+    SKGAdviceList advice(const QStringList& iIgnoredAdvice) override;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -145,7 +144,7 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) override;
+    SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) override;
 
 private Q_SLOTS:
     void onSplitShare();
