@@ -76,7 +76,11 @@ SKGUnitObject SKGUnitComboBox::getUnit()
 
 void SKGUnitComboBox::setUnit(const SKGUnitObject& iUnit)
 {
-    setText(iUnit.getSymbol());
+    if (text() != iUnit.getSymbol()) {
+        setText(iUnit.getSymbol());
+
+        emit unitChanged();
+    }
 }
 
 void SKGUnitComboBox::refershList()
