@@ -34,10 +34,9 @@ SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamed
 {}
 
 SKGCategoryObject::~SKGCategoryObject()
-{}
+    = default;
 
-SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject) : SKGNamedObject(iObject)
-{}
+SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject) = default;
 
 SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
 
@@ -69,7 +68,7 @@ SKGError SKGCategoryObject::setName(const QString& iName)
 QString SKGCategoryObject::getWhereclauseId() const
 {
     // Could we use the id
-    QString output = SKGObjectBase::getWhereclauseId();
+    QString output = SKGObjectBase::getWhereclauseId();  // clazy:exclude=skipped-base-method
     if (output.isEmpty()) {
         if (!(getAttribute(QStringLiteral("t_name")).isEmpty())) {
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QStringLiteral("t_name"))) % '\'';
@@ -272,6 +271,16 @@ bool SKGCategoryObject::isBookmarked() const
     return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? true : false);
 }
 
+SKGError SKGCategoryObject::setClosed(bool iClosed)
+{
+    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+}
+
+bool SKGCategoryObject::isClosed() const
+{
+    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y") ? true : false);
+}
+
 SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
 {
     SKGError err;
