@@ -65,7 +65,15 @@ QVariantList SKGReportBank::getAlarms()
                     SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
                     QVariantList item;  // clazy:exclude=container-inside-loop
-                    item.push_back(alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false), doc->formatMoney(alarm.Limit, primary, false), doc->formatMoney(alarm.Amount - alarm.Limit, primary, false)));
+                    // Build the message
+                    if (alarm.Message.contains(QLatin1String("%3"))) {
+                        alarm.Message = alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false), doc->formatMoney(alarm.Limit, primary, false), doc->formatMoney(alarm.Amount - alarm.Limit, primary, false));
+                    } else if (alarm.Message.contains(QLatin1String("%2"))) {
+                        alarm.Message = alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false), doc->formatMoney(alarm.Limit, primary, false));
+                    } else if (alarm.Message.contains(QLatin1String("%1"))) {
+                        alarm.Message = alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false));
+                    }
+                    item.push_back(alarm.Message);
                     item.push_back(alarm.Amount);
                     item.push_back(alarm.Limit);
                     item.push_back(alarm.Amount - alarm.Limit);
@@ -232,7 +240,7 @@ QVariantList SKGReportBank::getPortfolio()
                               << current2.initalAmount
                               << current2.currentAmount
                               << current2.currentAmount - current2.initalAmount
-                              << (current2.initalAmount == 0.0 ? 0.0 : (current2.currentAmount - current2.initalAmount) / current2.initalAmount);
+                              << (current2.initalAmount == 0.0 ? 0.0 : 100.0 * (current2.currentAmount - current2.initalAmount) / current2.initalAmount);
                         table << QVariant(line2);
                     }
                 }
@@ -343,7 +351,10 @@ QVariantList SKGReportBank::getAccountTable()
                         if (!closed || qAbs(v1) > 0.01 || qAbs(v2) > 0.01 || qAbs(v3) > 0.01) {
                             QString icon = account.getAttribute(QStringLiteral("t_ICON"));
                             if (!icon.isEmpty()) {
-                                icon = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
+                                QString iconfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
+                                if (!iconfile.isEmpty()) {
+                                    icon = iconfile;
+                                }
                             }
                             table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
                                             << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QStringLiteral("t_BANK")) << icon);
@@ -410,14 +421,12 @@ QVariantList SKGReportBank::getBankTable()
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
                         QString name = account.getAttribute(QStringLiteral("t_BANK"));
-                        // 320114 vvvv
-                        if (name.isEmpty()) {
-                            name = i18nc("Noun", "Unknown");
-                        }
-                        // 320114 ^^^^
                         QString icon = account.getAttribute(QStringLiteral("t_ICON"));
                         if (!icon.isEmpty()) {
-                            icon = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
+                            QString iconfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
+                            if (!iconfile.isEmpty()) {
+                                icon = iconfile;
+                            }
                         }
                         bool open = !account.isClosed();
                         if (name != currentName) {
@@ -626,9 +635,9 @@ double SKGReportBank::getNetWorth(bool iTransfert, bool iTracker)
     return output;
 }
 
-QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iTransfert, bool iTracker, const QString& iWhereClause1, const QString& iWhereClause2)
+QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iGrouped, bool iTransfert, bool iTracker, const QString& iWhereClause1, const QString& iWhereClause2)
 {
-    QString cacheId = QStringLiteral("getIncomeVsExpenditure-") % (iOnSubOperation ? QStringLiteral("Y") : QStringLiteral("N")) % (iTransfert ? QStringLiteral("Y") : QStringLiteral("N")) % (iTracker ? QStringLiteral("Y") : QStringLiteral("N")) % iWhereClause1 % iWhereClause2;
+    QString cacheId = QStringLiteral("getIncomeVsExpenditure-") % (iOnSubOperation ? QStringLiteral("Y") : QStringLiteral("N")) % (iGrouped ? QStringLiteral("Y") : QStringLiteral("N")) % (iTransfert ? QStringLiteral("Y") : QStringLiteral("N")) % (iTracker ? QStringLiteral("Y") : QStringLiteral("N")) % iWhereClause1 % iWhereClause2;
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10);
@@ -649,11 +658,13 @@ QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iT
 
             SKGError err = doc->executeSelectSqliteOrder(
                                "SELECT TOTAL(" % amount % "), '1'  from " % tableDb % " WHERE " % wc1 % " AND t_TYPEACCOUNT<>'L'"
+                               % (iGrouped ? "" : " AND i_group_id=0")
                                % (iTransfert ? "" : " AND t_TRANSFER='N'")
                                % (iTracker ? "" : " AND t_REFUND=''")
                                % " group by t_TYPEEXPENSE "
                                % " UNION ALL "
                                % "SELECT TOTAL(" % amount % "), '2'  from " % tableDb % " WHERE " % wc2 % " AND t_TYPEACCOUNT<>'L'"
+                               % (iGrouped ? "" : " AND i_group_id=0")
                                % (iTransfert ? "" : " AND t_TRANSFER='N'")
                                % (iTracker ? "" : " AND t_REFUND=''")
                                % " group by t_TYPEEXPENSE ",
