@@ -298,7 +298,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
         }
         QString wc = getSelectSqlOrder(addSql);
 
-        SKGDocument* doc = getDocument();
+        SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, APPLYTEMPLATE, false);
             if (!list.isEmpty()) {
@@ -309,10 +309,10 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
 
                 // Get operations to modify
                 SKGObjectBase::SKGListSKGObjectBase objectsToModify;
-                IFOKDO(err, doc->getObjects(QStringLiteral("v_operation"), wc, objectsToModify))
+                IFOKDO(err, doc->getObjects(QStringLiteral("v_operation_prop"), wc, objectsToModify))
                 int nb = objectsToModify.count();
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGOperationObject operationObj(objectsToModify.at(i));
+                    SKGOperationObject operationObj(doc, SKGServices::stringToInt(objectsToModify.at(i).getAttribute(QStringLiteral("i_OPID"))));
 
                     SKGOperationObject op;
                     IFOKDO(err, templateToApply.duplicate(op))
