@@ -68,7 +68,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGCalculatorEdit();
+    ~SKGCalculatorEdit() override;
 
     /**
      * Get the mode
@@ -134,13 +134,13 @@ protected:
      * This event handler, for event event, can be reimplemented in a subclass to receive key press events for the widget.
      * @param iEvent the event
      */
-    virtual void keyPressEvent(QKeyEvent* iEvent) override;
+    void keyPressEvent(QKeyEvent* iEvent) override;
 
     /**
      * This event handler can be reimplemented in a subclass to receive keyboard focus events (focus lost) for the widget. The events is passed in the event parameter.
      * @param iEvent the event
      */
-    virtual void focusOutEvent(QFocusEvent* iEvent) override;
+    void focusOutEvent(QFocusEvent* iEvent) override;
 
 private:
     Q_DISABLE_COPY(SKGCalculatorEdit)
