@@ -44,10 +44,14 @@ SKGDateEdit::Mode SKGDateEdit::mode() const
 
 void SKGDateEdit::setMode(Mode iMode)
 {
-    m_mode = iMode;
+    if (iMode != m_mode) {
+        m_mode = iMode;
 
-    KPIM::KDateValidator* val = qobject_cast<KPIM::KDateValidator*>(const_cast<QValidator*>(validator()));
-    val->setFixupBehavior(m_mode == CURRENT ? KPIM::KDateValidator::FixupCurrent : m_mode == NEXT ? KPIM::KDateValidator::FixupForward : KPIM::KDateValidator::FixupBackward);
+        KPIM::KDateValidator* val = qobject_cast<KPIM::KDateValidator*>(const_cast<QValidator*>(validator()));
+        val->setFixupBehavior(m_mode == CURRENT ? KPIM::KDateValidator::FixupCurrent : m_mode == NEXT ? KPIM::KDateValidator::FixupForward : KPIM::KDateValidator::FixupBackward);
+
+        emit modeChanged();
+    }
 }
 
 
