@@ -30,10 +30,9 @@ SKGInterfacePlugin::SKGInterfacePlugin(QObject* iParent)
 SKGInterfacePlugin::~SKGInterfacePlugin()
     = default;
 
-bool SKGInterfacePlugin::processArguments(const QStringList& iArgument)
+QStringList SKGInterfacePlugin::processArguments(const QStringList& iArgument)
 {
-    Q_UNUSED(iArgument);
-    return false;
+    return iArgument;
 }
 
 void SKGInterfacePlugin::close()
