@@ -32,12 +32,12 @@ SKGPeriodEdit::SKGPeriodEdit(QWidget* iParent, bool iModeEnabled)
 {
     ui.setupUi(this);
 
-    ui.kPeriod->addItem(i18nc("Period mode", "All Dates"), SKGPeriodEdit::ALL);
-    ui.kPeriod->addItem(i18nc("Period mode", "Current..."), SKGPeriodEdit::CURRENT);
-    ui.kPeriod->addItem(i18nc("Period mode", "Previous..."), SKGPeriodEdit::PREVIOUS);
-    ui.kPeriod->addItem(i18nc("Period mode", "Last..."), SKGPeriodEdit::LAST);
-    ui.kPeriod->addItem(i18nc("Period mode", "Custom..."), SKGPeriodEdit::CUSTOM);
-    ui.kPeriod->addItem(i18nc("Period mode", "Timeline..."), SKGPeriodEdit::TIMELINE);
+    ui.kPeriod->addItem(i18nc("Period mode", "All Dates"), int(SKGPeriodEdit::ALL));
+    ui.kPeriod->addItem(i18nc("Period mode", "Current..."), int(SKGPeriodEdit::CURRENT));
+    ui.kPeriod->addItem(i18nc("Period mode", "Previous..."), int(SKGPeriodEdit::PREVIOUS));
+    ui.kPeriod->addItem(i18nc("Period mode", "Last..."), int(SKGPeriodEdit::LAST));
+    ui.kPeriod->addItem(i18nc("Period mode", "Custom..."), int(SKGPeriodEdit::CUSTOM));
+    ui.kPeriod->addItem(i18nc("Period mode", "Timeline..."), int(SKGPeriodEdit::TIMELINE));
 
     ui.kInterval->addItem(i18nc("Period interval", "day(s)"), 0);
     ui.kInterval->addItem(i18nc("Period interval", "week(s)"), 1);
