@@ -55,7 +55,8 @@ public:
                     LINE,
                     STACKAREA,
                     BUBBLE,
-                    STACKCOLUMNS
+                    STACKCOLUMNS,
+                    TREEMAP
                    };
     /**
      * Graph type
