@@ -733,6 +733,37 @@ public:
      */
     virtual SKGError refreshViewsIndexesAndTriggers(bool iForce = false) const;
 
+    /**
+     * Get formated money
+     * @param iValue value
+     * @param iUnit unit
+     * @param iHtml colored output
+     * @return formated value in red or black
+     */
+    Q_INVOKABLE virtual QString formatMoney(double iValue, const SKGServices::SKGUnitInfo& iUnit, bool iHtml = true) const;
+
+    /**
+     * Get formated money in primary unit
+     * @param iValue value
+     * @return formated value in red or black
+     */
+    Q_INVOKABLE virtual QString formatPrimaryMoney(double iValue) const;
+
+    /**
+     * Get formated money in primary unit
+     * @param iValue value
+     * @return formated value in red or black
+     */
+    Q_INVOKABLE virtual QString formatSecondaryMoney(double iValue) const;
+
+    /**
+     * Get formated percentage
+     * @param iValue value
+     * @param iInvertColors to set positive value in red and negative values in green
+     * @return formated value in red or black
+     */
+    Q_INVOKABLE virtual QString formatPercentage(double iValue, bool iInvertColors = false) const;
+
 public Q_SLOTS:
 
     /**
@@ -905,37 +936,6 @@ public Q_SLOTS:
      */
     virtual void setBackupParameters(const QString& iPrefix = QString(), const QString& iSuffix = QString()) const;
 
-    /**
-     * Get formated money
-     * @param iValue value
-     * @param iUnit unit
-     * @param iHtml colored output
-     * @return formated value in red or black
-     */
-    virtual QString formatMoney(double iValue, const SKGServices::SKGUnitInfo& iUnit, bool iHtml = true) const;
-
-    /**
-     * Get formated money in primary unit
-     * @param iValue value
-     * @return formated value in red or black
-     */
-    virtual QString formatPrimaryMoney(double iValue) const;
-
-    /**
-     * Get formated money in primary unit
-     * @param iValue value
-     * @return formated value in red or black
-     */
-    virtual QString formatSecondaryMoney(double iValue) const;
-
-    /**
-     * Get formated percentage
-     * @param iValue value
-     * @param iInvertColors to set positive value in red and negative values in green
-     * @return formated value in red or black
-     */
-    virtual QString formatPercentage(double iValue, bool iInvertColors = false) const;
-
 Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
