@@ -63,7 +63,7 @@ SKGError SKGNodeObject::setName(const QString& iName)
 QString SKGNodeObject::getWhereclauseId() const
 {
     // Could we use the id
-    QString output = SKGObjectBase::getWhereclauseId();
+    QString output = SKGObjectBase::getWhereclauseId();  // clazy:exclude=skipped-base-method
     if (output.isEmpty()) {
         if (!(getAttribute(QStringLiteral("t_name")).isEmpty())) {
             output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QStringLiteral("t_name"))) % '\'';
