@@ -73,9 +73,9 @@ class Q_EXPORT_SQLDRIVER_SQLITE QSQLiteDriver : public QSqlDriver
     Q_OBJECT
     friend class QSQLiteResultPrivate;
 public:
-    explicit QSQLiteDriver(QObject* parent = 0);
-    explicit QSQLiteDriver(sqlite3* connection, QObject* parent = 0);
-    ~QSQLiteDriver();
+    explicit QSQLiteDriver(QObject* parent = nullptr);
+    explicit QSQLiteDriver(sqlite3* connection, QObject* parent = nullptr);
+    ~QSQLiteDriver() override;
     bool hasFeature(DriverFeature f) const Q_DECL_OVERRIDE;
     bool open(const QString& db,
               const QString& user,
