@@ -126,7 +126,7 @@ int main(int argc, char** argv)
     parser.addVersionOption();
     parser.addHelpOption();
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[URL]"), i18nc("Application argument", "Document to open")));
-    QCommandLineOption envOption(QStringList() << "e" << "env", i18nc("Application argument", "Display environment variables used by this application."));
+    QCommandLineOption envOption(QStringList() << QStringLiteral("e") << QStringLiteral("env"), i18nc("Application argument", "Display environment variables used by this application."));
     parser.addOption(envOption);
 
     about.setupCommandLine(&parser);
