@@ -34,8 +34,10 @@ class SKGXXXPluginWidget : public SKGTabPage
 public:
     /**
      * Default Constructor
+     * @param iParent the parent widget
+     * @param iDocument the document
      */
-    explicit SKGXXXPluginWidget(SKGDocument* iDocument);
+    explicit SKGXXXPluginWidget(QWidget* iParent, SKGDocument* iDocument);
 
     /**
      * Default Destructor
