@@ -462,7 +462,7 @@ void ModelTest::data()
             QVariant textAlignmentVariant = model->data(model->index(r, c), Qt::TextAlignmentRole);
             if (textAlignmentVariant.isValid()) {
                 int alignment = textAlignmentVariant.toInt();
-                Q_ASSERT(alignment == (alignment & (Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask)));
+                Q_ASSERT(static_cast<unsigned int>(alignment) == static_cast<unsigned int>(alignment & (Qt::AlignHorizontal_Mask | Qt::AlignVertical_Mask)));
             }
 
             // General Purpose roles that should return a QColor
