@@ -121,6 +121,24 @@ int main(int argc, char** argv)
         SKGTESTACCOUNT(document1, "A000400",  255912.039);
     }
 
+    {
+        // Test import cat
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.load()"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportkmy4/bug_import_cat.skg"), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_KMY"), err);
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportkmy4/bug_import_cat.kmy"));
+            SKGTESTERROR(QStringLiteral("KMY.importFile"), imp1.importFile(), true);
+
+            int nb = 0;
+            SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("category"), QStringLiteral("t_name='Cantine'"), nb), true);
+
+            SKGTEST(QStringLiteral("document1:nb category"), nb, 1);
+        }
+    }
+
     // End test
     SKGENDTEST();
 }
