@@ -44,7 +44,7 @@ int main(int argc, char** argv)
         {
             // Scope of the transaction
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MMB"), err);
-            SKGImportExportManager impmissing(&document1, QUrl(QStringLiteral("missingfile.mmb")));
+            SKGImportExportManager impmissing(&document1, QUrl::fromLocalFile(QStringLiteral("missingfile.mmb")));
             SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false);
 
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmmb/test.mmb"));
